body {
  color: #000000;
  background-image: url('/brickwall.png');
  margin-left: 5%;
  margin-right: 5%;
  font-family: 'Ubuntu';
  font-size: 1em;
}

#container {
    width: 960px;
    color: #666;
}

#container a {
    font-weight: bold;
    color: black;
}

.clearfix {
    clear:both;
}

a {
  color: rgb(80,0,0);
}
a:link {
  text-decoration: none; 
}
a:visited {
  text-decoration: none;
}
a:hover {
  text-decoration: underline;
}
a:active {
  text-decoration: none;
}

h1        { color: #666; }
h2        { color: #999; text-indent: 0.5em; }
h3 { 
    color: rgb(40,0,0); 
    text-indent: 1em;
}
h4        { color: #aaa; }

p {

  margin-left: 1em;
  margin-top: 0.50em;
  margin-bottom: 0.50em;
}
.rcs {
  margin-top: 2em;
}

#header {
    clear:both;
}

#header .logo {
    float:left;
}

.footer {
  width: 100%;
  border-top: 1px solid #000042;
  margin-top: 2em;
}
.footer p {
  text-indent: 0em;
  font-size: 75%;
  clear: none;
}

i.postdate {
  color: rgb(50,0,0);
  font-size: 0.8em;
}

i.categories {
  color: #bbb;
  font-size: .85em;
}

.posttopic {
    font-size: 90%;
}

.post-item {

}

.post-item ul {
    list-style-type: square;
    display: block;
}


ul {
  list-style-type: none;
  display: inline;
}

#container li.postbox {
    width: 310px;
    height: 125px;
    padding: 5px;
    float:left;
}

#container li.postbox a {
    font-size: 0.95em;
    color: rgb(140,0,0);
}

li.postbox i.postdate {
  font-size: 1em;
  font-style: normal;
}

dt {
  font-weight: bold;
  font-size: 110%;
}

pre { 
    font-size: 1em;
    font-family: 'Ubuntu Mono';
}
.align-right { float:right; margin: 0 0 15px 15px; }
.align-left { float:left; margin: 0 15px 15px 0; }

/* navbar */

#navbar {

}
